# Rnd Logger

A python logger implementation for the Made Tech R&D department

## Testing

- run `make test`

## Creating a release

- Commit your changes to main and then create a release on Github. 
- This will trigger a Github action that will increment the version with the tag you have chosen and publish that version to PyPi
- Please use semantic versioning and version relative to the change you have made